.. _outputimage:

***********************
Output Image Generation
***********************

.. moduleauthor:: Warren Hack <help@stsci.edu>

.. currentmodule:: drizzlepac.outputimage

.. automodule:: drizzlepac.outputimage

.. autoclass:: OutputImage
   :members:
   :undoc-members:
